@@ -443,12 +443,15 @@ class Configuration(Model):
     value = JSONField(verbose_name='值')
 
     @staticmethod
-    def get(key: str, user=None):
+    def get(key: str, user=None, default: str = None):
         """从数据库获取一个值。
 
         用户可以指定为空，则表示获取全局配置项。
         """
         obj, created = Configuration.objects.get_or_create(key=key, user=user)
+        if created and default is not None:
+            obj.value = default
+            obj.save()
         return obj.value
 
     @staticmethod
