@@ -68,10 +68,10 @@ class TestCase(__TestCase):
         return self.assert_response(self.client.get(path, data), status_code, *groups)
 
     def assert_post(self, path: str, data, status_code: int, *groups):
-        return self.assert_response(self.client.post(path, data), status_code, *groups)
+        return self.assert_response(self.client.post(path, data, format='json'), status_code, *groups)
 
     def assert_patch(self, path: str, data, status_code: int, *groups):
-        return self.assert_response(self.client.patch(path, data), status_code, *groups)
+        return self.assert_response(self.client.patch(path, data, format='json'), status_code, *groups)
 
     def assert_delete(self, path: str, data, status_code: int, *groups):
         return self.assert_response(self.client.delete(path, data), status_code, *groups)
