@@ -4,9 +4,10 @@ import django.contrib.messages
 import django.core.exceptions
 import django.http
 import django.urls
-import django.views.generic
-import django.views.generic.detail
 import guardian.mixins
+from django.views.generic import TemplateView as DjangoTemplateView, FormView as DjangoFormView
+from django.views.generic.base import RedirectView as DjangoRedirectView
+from django.views.generic.detail import DetailView as DjangoDetailView, SingleObjectMixin as DjangoSingleObjectMixin
 from guardian.shortcuts import assign_perm
 
 __keep = (django.urls.reverse_lazy, django.urls.reverse, assign_perm)
@@ -60,15 +61,15 @@ class ContextMixin(PhyDjangoMixin, django.views.generic.base.ContextMixin):
         return kwargs
 
 
-class TemplateView(ContextMixin, django.views.generic.TemplateView):
+class TemplateView(ContextMixin, DjangoTemplateView):
     pass
 
 
-class DetailView(ContextMixin, django.views.generic.detail.DetailView):
+class DetailView(ContextMixin, DjangoDetailView):
     pass
 
 
-class FormView(ContextMixin, django.views.generic.FormView):
+class FormView(ContextMixin, DjangoFormView):
     template_name = 'phy_django/form.html'
 
     def get_context_data(self, **kwargs):
@@ -76,9 +77,9 @@ class FormView(ContextMixin, django.views.generic.FormView):
         return data
 
 
-class SingleObjectMixin(django.views.generic.detail.SingleObjectMixin):
+class SingleObjectMixin(DjangoSingleObjectMixin):
     pass
 
 
-class RedirectView(PhyDjangoMixin, django.views.generic.base.RedirectView):
+class RedirectView(PhyDjangoMixin, DjangoRedirectView):
     pass
